# About

## Development

ESSreduce is an open source project by the [European Spallation Source ERIC](https://ess.eu/) (ESS).

## License

ESSreduce is available as open source under the [BSD-3 license](https://opensource.org/license/BSD-3-Clause).

## Citing ESSreduce

Please cite the following:

[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.14523972.svg)](https://doi.org/10.5281/zenodo.14523972)

To cite a specific version of ESSreduce, select the desired version on Zenodo to get the corresponding DOI.

## Older versions of the documentation

Older versions of the documentation pages can be found under the assets of each [release](https://github.com/scipp/essreduce/releases).
Simply download the archive, unzip and view locally in a web browser.

## Source code and development

ESSreduce is hosted and developed [on GitHub](https://github.com/scipp/essreduce).
